#!/bin/sh

FILES_DIR="$HOME/files"
ARCHIVE_DIR="$FILES_DIR/4in1-old-versions"

fatal() {
	>&2 echo "error: $@"
	exit 1
}

usage() {
	>&2 echo "usage: $0 <filename> en|ru <new_version_number>"
}

[ $# -ne 3 ] && { usage; exit 1; }

INPUT="$1"
LANG="$2"
VERSION="$3"

case $LANG in
    en|ru) : ;;
    *) fatal "invalid language" ;;
esac

previous_version=$(( VERSION-1 ))
target_file="$FILES_DIR/4in1-$LANG.pdf"
archive_target_file="$ARCHIVE_DIR/4in1-$LANG-update$previous_version.pdf"

[ -d "$ARCHIVE_DIR" ] || {
	mkdir "$ARCHIVE_DIR"
	chmod 755 "$ARCHIVE_DIR"
	chgrp www-data "$ARCHIVE_DIR"
}

[ -e "$archive_target_file" ] && fatal "invalid version: file \"$archive_target_file\" already exists"

exiftool -author=idb "$INPUT"

mv "$target_file" "$archive_target_file"
mv "$INPUT" "$target_file"
